#include <stdio.h>
#include <stdlib.h>
#include <ctype.h>
#include <string.h>
#include <stdint.h>
#include <limits.h>
#include <math.h>

enum { MAX_PREC = 10000000 }; // maximum allowed precision

struct DecFracPart
{
    unsigned char *digits;
    size_t size;
    size_t allocated;
};

struct BinFracPart
{
    uint32_t *words;
    size_t size;
    size_t prec;
};

enum { BIT_PER_WORD = sizeof(((struct BinFracPart *) 0)->words[0]) * CHAR_BIT };

int
read_dec_frac_part(FILE *fin, struct DecFracPart *dfp)
{
    memset(dfp, 0, sizeof(*dfp));
    int c = getc(fin);
    while (isspace(c)) c = getc(fin);
    if (c == EOF) return EOF;
    if (!isdigit(c)) {
        ungetc(c, fin);
        return 0;
    }
    while (isdigit(c)) {
        if (dfp->size == dfp->allocated) {
            if (!(dfp->allocated *= 2)) dfp->allocated = 16;
            dfp->digits = realloc(dfp->digits, dfp->allocated * sizeof(dfp->digits[0]));
        }
        dfp->digits[dfp->size++] = c - '0';
        c = getc(fin);
    }
    ungetc(c, fin);
    return 1;
}

void
normalize_dec_frac_part(struct DecFracPart *dfp)
{
    while (dfp->size > 0 && !dfp->digits[dfp->size - 1])
        --dfp->size;
}

void
write_dec_frac_part(FILE *fout, const struct DecFracPart *dfp)
{
    for (size_t i = 0; i < dfp->size; ++i) {
        putc(dfp->digits[i] + '0', fout);
    }
}

unsigned
mul2p32_dec_frac_part(struct DecFracPart *dfp, int prec)
{
    if (!dfp->size) return 0;
    unsigned c = 0;
    if (prec >= BIT_PER_WORD) {
        for (ssize_t i = dfp->size - 1; i >= 0; --i) {
            unsigned long long val = (((unsigned long long) dfp->digits[i]) << BIT_PER_WORD) + c;
            c = val / 10;
            val %= 10;

            dfp->digits[i] = val;
        }
    } else {
        for (ssize_t i = dfp->size - 1; i >= 0; --i) {
            unsigned long long val = (((unsigned long long) dfp->digits[i]) << prec) + c;
            c = val / 10;
            val %= 10;
            dfp->digits[i] = val;
        }
        c <<= (BIT_PER_WORD - prec);
    }
    normalize_dec_frac_part(dfp);
    return c;
}

void
init_bin_frac_part(struct BinFracPart *bfp, int prec)
{
    memset(bfp, 0, sizeof(*bfp));
    bfp->size = (prec + BIT_PER_WORD - 1) / BIT_PER_WORD;
    bfp->words = calloc(bfp->size, sizeof(bfp->words[0]));
    bfp->prec = prec;
}

void
set_bit(struct BinFracPart *bfp, size_t pos, int bit)
{
    size_t offset = pos / BIT_PER_WORD;
    int shift = pos % BIT_PER_WORD;
    bfp->words[offset] |= (bit & 1) << (BIT_PER_WORD - 1 - shift);
}

int
get_bit(struct BinFracPart *bfp, size_t pos)
{
    size_t offset = pos / BIT_PER_WORD;
    int shift = pos % BIT_PER_WORD;
    return (bfp->words[offset] >> (BIT_PER_WORD - 1 - shift)) & 1;
}

int
add_bit(struct BinFracPart *bfp, size_t pos, int bit)
{
    if (!bit) return 0;
    int offset = pos / BIT_PER_WORD;
    int shift = pos % BIT_PER_WORD;
    unsigned value = (bit & 1) << (BIT_PER_WORD - 1 - shift);
    while (value && offset >= 0) {
        value = __builtin_add_overflow(value, bfp->words[offset], &bfp->words[offset]);
        --offset;
    }
    return value;
}

int
dectobin(struct BinFracPart *bfp, struct DecFracPart *dfp, int prec)
{
    init_bin_frac_part(bfp, prec);
    for (int i = 0; i < prec; i += BIT_PER_WORD) {
        unsigned bit32 = mul2p32_dec_frac_part(dfp, prec - i);
        size_t offset = i / BIT_PER_WORD;
        bfp->words[offset] |= bit32;
        if (!dfp->size) break;
    }
    // rounding
    int rnd = 0;
    if (dfp->size == 1 && dfp->digits[0] == 5) {
        // nearest even
        rnd = get_bit(bfp, prec - 1);
    } else if (dfp->size >= 1 && dfp->digits[0] >= 5) {
        rnd = 1;
    }
    return add_bit(bfp, prec - 1, rnd);
}

void
write_bin_frac_part(FILE *fout, const struct BinFracPart *bfp, int is_ovf)
{
    if (is_ovf) {
        fprintf(fout, "1 ");
    }
    for (int i = 0; i < bfp->size; ++i) {
        if (i > 0) putc(' ', fout);
        fprintf(fout, "%08x", (unsigned) bfp->words[i]);
    }
}

int main(void)
{
    int prec;
    scanf("%d", &prec);
    if (prec <= 0) abort();
    if (prec > MAX_PREC) abort();

    struct DecFracPart dfp;
    read_dec_frac_part(stdin, &dfp);
    normalize_dec_frac_part(&dfp);
    struct BinFracPart bfp;
    int ovf = dectobin(&bfp, &dfp, prec);
    write_bin_frac_part(stdout, &bfp, ovf);
    putchar('\n');
}
